local configPath = "limited_intervention"

local config = mwse.loadConfig(configPath)
if not config then
    config = {
        enableMod = true,
        divineInterventionsPerRank = 2,
        almsiviInterventionsPerRank = 2
    }
end


----------------------------------------------------
--Functions-----------------------------------------
----------------------------------------------------

local function getDivineInterventionsLeft()
    local imperialCult = tes3.getObject("chaplain ogrul").faction
    local data = tes3.player.data.limitedIntervention
    return (
        ( (imperialCult.playerRank + 1)  * config.divineInterventionsPerRank )
        - data.divineInterventionsCast
    )
end
local function getAlmsiviInterventionsLeft()
    local data = tes3.player.data.limitedIntervention
    local temple = tes3.getObject("adrusu rothrano").faction
    return (
        ( (temple.playerRank+1) * config.almsiviInterventionsPerRank )
        - data.almsiviInterventionsCast
    )
end

local function spellCast(e)
    local data = tes3.player.data.limitedIntervention
    if config.enableMod then
        local spell = e.source
        local isDivine = false
        local isAlmsivi = false
        for i=1, #spell.effects do
            if spell.effects[i].id == tes3.effect.divineIntervention then
                isDivine = true
            elseif spell.effects[i].id == tes3.effect.almsiviIntervention then
                isAlmsivi = true
            end
        end

        local imperialCult = tes3.getObject("chaplain ogrul").faction
        local temple = tes3.getObject("adrusu rothrano").faction--("Temple")

        if isDivine then
            if not imperialCult.playerJoined then
                e.castChance = 0
                tes3.messageBox("Seuls les membres du Culte imprial peuvent utiliser un sort d'Intervention divine.")
                return
            elseif getDivineInterventionsLeft() <= 0 then
                e.castChance = 0
                tes3.messageBox("Vous ne pouvez plus faire appel  une Intervention divine.")
            end
        end
        if isAlmsivi then
            if not temple.playerJoined then
                e.castChance = 0
                tes3.messageBox("Seuls les membres du Temple peuvent utiliser un sort d'Intervention d'ALMSIVI.")
                return
            elseif getAlmsiviInterventionsLeft() <= 0 then
                e.castChance = 0
                tes3.messageBox("Vous ne pouvez plus faire appel  une Intervention d'ALMSIVI.")
            end
        end
    end
end
event.register("spellCast", spellCast)


local function spellCasted(e)
    if config.enableMod then
        local data = tes3.player.data.limitedIntervention
        local spell = e.source
        local isDivine = false
        local isAlmsivi = false
        for i=1, #spell.effects do
            if spell.effects[i].id == tes3.effect.divineIntervention then
                isDivine = true
            elseif spell.effects[i].id == tes3.effect.almsiviIntervention then
                isAlmsivi = true
            end
        end
        if isDivine then
            data.divineInterventionsCast = data.divineInterventionsCast + 1
            tes3.messageBox("Vous pouvez encore lancer Intervention divine %d fois.", getDivineInterventionsLeft())
        elseif isAlmsivi then
            data.almsiviInterventionsCast = data.almsiviInterventionsCast + 1
            tes3.messageBox("Vous pouvez encore lancer Intervention d'ALMSIVI %d fois.", getAlmsiviInterventionsLeft())
        end
    end
end
event.register("spellCasted", spellCasted)

local function loaded()
    tes3.player.data.limitedIntervention = tes3.player.data.limitedIntervention or {}
    local data = tes3.player.data.limitedIntervention
    data.divineInterventionsCast = data.divineInterventionsCast or 0
    data.almsiviInterventionsCast = data.almsiviInterventionsCast or 0
end

event.register("loaded", loaded)

---------------------------------------------------
--MCM
---------------------------------------------------

local function registerMCM()
    local  sideBarDefault = (
        "Ce mod limite le nombre de fois o vous pouvez lancer un sort " ..
        "d'Intervention divine ou d'ALMSIVI en fonction de votre rang respectif dans le " ..
        " Culte imprial et le Temple, et restreint leur usage aux membres de ces factions."
    )


    local function addSideBar(component)
        component.sidebar:createInfo{ text = sideBarDefault}
        component.sidebar:createHyperLink{
            text = "Par Merlord",
            exec = "start https://www.nexusmods.com/users/3040468?tab=user+files",
            postCreate = (
                function(self)
                    self.elements.outerContainer.borderAllSides = self.indent
                    self.elements.outerContainer.alignY = 1.0
                    self.elements.outerContainer.layoutHeightFraction = 1.0
                    self.elements.info.layoutOriginFractionX = 0.5
                end
            ),
        }

    end

    local template = mwse.mcm.createTemplate("Interventions limites")
    template:saveOnClose(configPath, config)
    template:register()

    local page = template:createSideBarPage()
    addSideBar(page)

    page:createOnOffButton{
        label = "Activer le mod ?",
        description = "Active ou dsactive \"Interventions limites\".",
        variable = mwse.mcm.createTableVariable{
            id = "enableMod",
            table = config
        }
    }

    page:createSlider{
        label = "Lancers d'Intervention divine par rang du Culte imprial",
        description = "Dtermine le nombre de lancers d'Intervention divine que vous obtenez par rang gagns dans le Culte imprial (par dfaut : 2).",
        max = 10,
        step = 1,
        jump = 1,
        variable = mwse.mcm.createTableVariable{
            id = "divineInterventionsPerRank",
            table = config
        }
    }
    page:createSlider{
        label = "Lancers d'Intervention d'ALMSIVI par rang du Temple",
        description =  "Dtermine le nombre de lancers d'Intervention d'ALMSIVI que vous obtenez par rang gagns dans le Temple (par dfaut : 2).",
        max = 10,
        step = 1,
        jump = 1,
        variable = mwse.mcm.createTableVariable{
            id = "almsiviInterventionsPerRank",
            table = config
        }
    }
end

event.register("modConfigReady", registerMCM)
